# MysqlRoles
Role Based Access Control (RBAC) for mysql

## Documentation
See http://www.rbirm.us/MysqlRoles/

## How this is used
There are two parts to this application:
* RoleManage
* RoleServ

RoleManage is meant to be installed on or in cooperation with clients to allow for MysqlRoles to manage their users.

RoleServ is meant to be installed on or in cooperation with the central user server.
